summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJohn Hood <cgull@glup.org>2016-12-29 16:33:22 -0500
committerJohn Hood <cgull@glup.org>2016-12-29 16:33:22 -0500
commit78ba5fddb6839058e7d3b29db5fc89d69b8609b2 (patch)
tree552a6e8fb9c9e49e0848d3714efffd039652ff11
parentc2ff43f83d58bc21de861fd7810185f93e051abe (diff)
macosx/build.sh: build-a-bottle option changedmosh-1.3.0-rc1
-rwxr-xr-xmacosx/brew-deps.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/macosx/brew-deps.sh b/macosx/brew-deps.sh
index ddf28f0..fb236b7 100755
--- a/macosx/brew-deps.sh
+++ b/macosx/brew-deps.sh
@@ -42,15 +42,15 @@ deps()
# Runtime dependencies are required to support the targeted OS X
# version, static libraries, and fat binaries for the package build.
#
# This reinstalls protobuf with --universal --bottle to get a fat
# library that will run on any machine. (This takes about 15 minutes
# on current Travis infrastructure.)
#
package_deps()
{
deps
brew rm protobuf
- brew install protobuf --universal --bottle
+ brew install protobuf --universal --build-bottle
}
#
@@ -42,15 +42,15 @@ deps()
# version, static libraries, and fat binaries for the package build.
#
-# This reinstalls protobuf with --universal --bottle to get a fat
-# library that will run on any machine. (This takes about 15 minutes
-# on current Travis infrastructure.)
+# This reinstalls protobuf with --universal --build-bottle to get a
+# fat library that will run on any machine. (This takes about 15
+# minutes on current Travis infrastructure.)
#
package_deps()